@@ -5,23 +5,9 @@ library("testthat")
 library("mgcv")
 library("gratia")
 
-context("Testing smooth_samples() methods")
-
-set.seed(12398)
-dat <- gamSim(1, n = 400, dist = "normal", scale = 2, verbose = FALSE)
-m1 <- gam(y ~ s(x0), data = dat, method = "REML")
-m2 <- gam(y ~ s(x0) + s(x1) + s(x2) + s(x3), data = dat, method = "REML")
-
-set.seed(34786)
-dat2 <- gamSim(4, verbose = FALSE)
-m3 <- gam(y ~ fac + s(x2, by = fac) + s(x0), data = dat2, method = "REML")
-
-set.seed(42)
-cont_by_data <- gamSim(3, n = 400, verbose = FALSE)
-cont_by_gam <- gam(y ~ s(x2, by = x1), data = cont_by_data)
-
 test_that("smooth_samples works for a continuous by GAM", {
-    expect_silent(sm <- smooth_samples(cont_by_gam, n = 5, n_vals = 100, seed = 42))
+    expect_silent(sm <- smooth_samples(su_m_cont_by, n = 5, n_vals = 100,
+                                       seed = 42))
     expect_s3_class(sm, c("smooth_samples", "posterior_samples", "tbl_df",
                           "tbl", "data.frame"))
     ## 500 == 1 smooth * 5 * 100
@@ -30,7 +16,8 @@ test_that("smooth_samples works for a continuous by GAM", {
 })
 
 test_that("smooth_samples works for a simple GAM", {
-    expect_silent(sm <- smooth_samples(m1, n = 5, n_vals = 100, seed = 42))
+    expect_silent(sm <- smooth_samples(m_1_smooth, n = 5, n_vals = 100,
+                                       seed = 42))
     expect_s3_class(sm, c("smooth_samples", "posterior_samples", "tbl_df",
                           "tbl", "data.frame"))
     ## 500 == 1 smooth * 5 * 100
@@ -39,7 +26,7 @@ test_that("smooth_samples works for a simple GAM", {
 })
 
 test_that("smooth_samples works for a multi-smooth GAM", {
-    expect_silent(sm <- smooth_samples(m2, n = 5, n_vals = 100, seed = 42))
+    expect_silent(sm <- smooth_samples(m_gam, n = 5, n_vals = 100, seed = 42))
     expect_s3_class(sm, c("smooth_samples", "posterior_samples", "tbl_df",
                           "tbl", "data.frame"))
     ## 2000 == 4 smooths * 5 * 100
@@ -48,7 +35,8 @@ test_that("smooth_samples works for a multi-smooth GAM", {
 })
 
 test_that("smooth_samples works for a multi-smooth factor by GAM", {
-    expect_silent(sm <- smooth_samples(m3, n = 5, n_vals = 100, seed = 42))
+    expect_silent(sm <- smooth_samples(su_m_factor_by, n = 5, n_vals = 100,
+                                       seed = 42))
     expect_s3_class(sm, c("smooth_samples", "posterior_samples", "tbl_df",
                           "tbl", "data.frame"))
     ## 2000 == 1 + (1 * 3) smooths * 5 * 100
@@ -63,42 +51,64 @@ test_that("smooth_samples() fails if not suitable method available", {
 })
 
 test_that("smooth_samples sets seed when seed not provided", {
-    expect_silent(smooth_samples(m2, seed = NULL))
+    expect_silent(smooth_samples(m_gam, seed = NULL))
 })
 
 test_that("smooth_samples works with term provided", {
-    expect_silent(sm <- smooth_samples(m2, term = "s(x2)", seed = 42))
+    expect_silent(sm <- smooth_samples(m_gam, term = "s(x2)", seed = 42))
 })
 
 test_that("smooth_samples errors with invalid term provided", {
-    expect_error(sm <- smooth_samples(m2, term = "s(x10)", seed = 42),
+    expect_error(sm <- smooth_samples(m_gam, term = "s(x10)", seed = 42),
                  "None of the terms matched a smooth.", fixed = TRUE)
 })
 
-context("Testing fitted_samples() methods")
+# from #121
+test_that("smooth_samples gets the right factor by smooth: #121", {
+    expect_silent(sm <- smooth_samples(su_m_factor_by, n = 5, n_vals = 100,
+                                       term = "s(x2):fac2", seed = 42))
+    # factor level of `fac` column should be 2
+    expect_identical(all(sm["fac"] == 2), TRUE)
+})
+
+# from #121 - problems when model contains ranef smooths
+test_that("smooth_samples ignores ranef smooths: #121", {
+    expect_message(sm <- smooth_samples(rm1, n = 5, n_vals = 100, seed = 42),
+                   "Random effect smooths not currently supported.")
+    # given n and n_vals and 4 smooths, nrow == 2000L
+    expect_identical(nrow(sm), 2000L)
+    # shouldn't have "s(fac)" in sm
+    expect_identical(any(sm$smooth == "s(fac)"), FALSE)
+})
+
+test_that("smooth_samples fails if no smooths left to sample from", {
+    expect_error(sm <- smooth_samples(rm1, term = "s(fac)",
+                                        n = 5, n_vals = 100, seed = 42),
+                 "No smooths left that can be sampled from.")
+})
 
 test_that("fitted_samples works for a simple GAM", {
-    expect_silent(sm <- fitted_samples(m1, n = 5, seed = 42))
+    expect_silent(sm <- fitted_samples(m_1_smooth, n = 5, seed = 42))
     expect_s3_class(sm, c("fitted_samples", "posterior_samples", "tbl_df",
                           "tbl", "data.frame"))
-    ## 2000 == 5 * 400 (nrow(dat))
-    expect_identical(NROW(sm), 2000L)
+    ## 1000 == 5 * 200 (nrow(dat))
+    expect_identical(NROW(sm), 1000L)
     expect_identical(NCOL(sm), 3L) # 3 cols
     expect_named(sm, expected = c("row", "draw", "fitted"))
 })
 
 test_that("fitted_samples works for a multi-smooth GAM", {
-    expect_silent(sm <- fitted_samples(m2, n = 5, seed = 42))
+    expect_silent(sm <- fitted_samples(m_gam, n = 5, seed = 42))
     expect_s3_class(sm, c("fitted_samples", "posterior_samples", "tbl_df",
                           "tbl", "data.frame"))
-    ## 2000 == 5 draws * 400 observations in data
-    expect_identical(NROW(sm), 2000L)
+    ## 5000 == 5 draws * 1000 observations in data
+    expect_identical(NROW(sm), 5000L)
     expect_identical(NCOL(sm), 3L) # 3 cols
     expect_named(sm, expected = c("row", "draw", "fitted"))
 })
 
 test_that("fitted_samples works for a multi-smooth factor by GAM", {
-    expect_silent(sm <- fitted_samples(m3, n = 5, seed = 42))
+    expect_silent(sm <- fitted_samples(su_m_factor_by, n = 5, seed = 42))
     expect_s3_class(sm, c("fitted_samples", "posterior_samples", "tbl_df",
                           "tbl", "data.frame"))
     ## 2000 == 5 draws * 400 observations in data
@@ -108,7 +118,7 @@ test_that("fitted_samples works for a multi-smooth factor by GAM", {
 })
 
 test_that("fitted_samples sets seed when seed not provided", {
-    expect_silent(fitted_samples(m2, seed = NULL))
+    expect_silent(fitted_samples(m_gam, seed = NULL))
 })
 
 test_that("fitted_samples() fails if not suitable method available", {
@@ -117,30 +127,28 @@ test_that("fitted_samples() fails if not suitable method available", {
                  fixed = TRUE)
 })
 
-context("Testing predicted_samples() methods")
-
 test_that("predicted_samples works for a simple GAM", {
-    expect_silent(sm <- predicted_samples(m1, n = 5, seed = 42))
+    expect_silent(sm <- predicted_samples(m_1_smooth, n = 5, seed = 42))
     expect_s3_class(sm, c("predicted_samples", "posterior_samples", "tbl_df",
                           "tbl", "data.frame"))
-    ## 2000 == 5 * 400 (nrow(dat))
-    expect_identical(NROW(sm), 2000L)
+    ## 2000 == 5 * 100 (nrow(dat))
+    expect_identical(NROW(sm), 1000L)
     expect_identical(NCOL(sm), 3L) # 3 cols
     expect_named(sm, expected = c("row", "draw", "response"))
 })
 
 test_that("predicted_samples works for a multi-smooth GAM", {
-    expect_silent(sm <- predicted_samples(m2, n = 5, seed = 42))
+    expect_silent(sm <- predicted_samples(m_gam, n = 5, seed = 42))
     expect_s3_class(sm, c("predicted_samples", "posterior_samples", "tbl_df",
                           "tbl", "data.frame"))
-    ## 2000 == 5 draws * 400 observations in data
-    expect_identical(NROW(sm), 2000L)
+    ## 5000 == 5 draws * 1000 observations in data
+    expect_identical(NROW(sm), 5000L)
     expect_identical(NCOL(sm), 3L) # 3 cols
     expect_named(sm, expected = c("row", "draw", "response"))
 })
 
 test_that("predicted_samples works for a multi-smooth factor by GAM", {
-    expect_silent(sm <- predicted_samples(m3, n = 5, seed = 42))
+    expect_silent(sm <- predicted_samples(su_m_factor_by, n = 5, seed = 42))
     expect_s3_class(sm, c("predicted_samples", "posterior_samples", "tbl_df",
                           "tbl", "data.frame"))
     ## 2000 == 5 draws * 400 observations in data
@@ -150,7 +158,7 @@ test_that("predicted_samples works for a multi-smooth factor by GAM", {
 })
 
 test_that("predicted_samples sets seed when seed not provided", {
-    expect_silent(predicted_samples(m2, seed = NULL))
+    expect_silent(predicted_samples(m_gam, seed = NULL))
 })
 
 test_that("predicted_samples() fails if not suitable method available", {
@@ -159,8 +167,6 @@ test_that("predicted_samples() fails if not suitable method available", {
                  fixed = TRUE)
 })
 
-context("Testing posterior_samples() methods")
-
 test_that("posterior_samples() fails if not suitable method available", {
     expect_error(posterior_samples(1:10),
                  "Don't know how to sample from the posterior of <integer>",
